@@ -273,6 +273,8 @@ class Exploit < Msf::Module
     return mixins
   end
 
+  attr_accessor :needs_cleanup
+
   #
   # Creates an instance of the exploit module.  Mad skillz.
   #
@@ -321,7 +323,7 @@ class Exploit < Msf::Module
     end
 
     # Initialize exploit datastore with target information
-    import_target_datastore
+    import_target_defaults
 
     # All exploits can increase the delay when waiting for a session.
     # However, this only applies to aggressive exploits.
@@ -686,7 +688,7 @@ class Exploit < Msf::Module
     target_idx =
       begin
         Integer(datastore['TARGET'])
-      rescue ArgumentError, TypeError
+      rescue TypeError, ArgumentError
         datastore['TARGET']
       end
 
@@ -701,14 +703,6 @@ class Exploit < Msf::Module
     return (target_idx) ? target_idx.to_i : nil
   end
 
-  #
-  # Import the target's DefaultOptions hash into the datastore.
-  #
-  def import_target_datastore
-    return unless target && target.default_options
-    datastore.import_options_from_hash(target.default_options)
-  end
-
   #
   # Returns the target's platform, or the one assigned to the module itself.
   #
@@ -741,6 +735,8 @@ class Exploit < Msf::Module
   def is_payload_compatible?(name)
     p = framework.payloads[name]
 
+    return false unless p
+
     # Skip over payloads that are too big
     return false if payload_space && p.cached_size && p.cached_size > payload_space
 
@@ -750,6 +746,10 @@ class Exploit < Msf::Module
     # what not?
     return false if !compatible?(pi)
 
+    if self.needs_cleanup && !pi.can_cleanup
+      return false
+    end
+
     # If the payload is privileged but the exploit does not give
     # privileged access, then fail it.
     return false if !self.privileged && pi.privileged
