@@ -31,12 +31,21 @@ module Msf::Module::FullName
     def shortname
       refname.split('/').last
     end
+
+    #
+    # Returns a list of alternate names the module might go by.
+    #
+    def aliases
+      const_defined?(:Aliases) ? const_get(:Aliases) : []
+    end
   end
 
   #
   # Instance Methods
   #
 
+  attr_accessor :aliased_as
+
   #
   # Returns the module's framework full reference name.  This is the
   # short name that end-users work with (refname) plus the type
@@ -45,7 +54,7 @@ module Msf::Module::FullName
   # payloads/windows/shell/reverse_tcp
   #
   def fullname
-    self.class.fullname
+    aliased_as || self.class.fullname
   end
 
   #
@@ -55,16 +64,16 @@ module Msf::Module::FullName
   # windows/shell/reverse_tcp
   #
   def refname
-    self.class.refname
+    fullname.sub(type + '/', '')
   end
 
   #
   # Returns the module's framework prompt-friendly name.
   #
-  # reverse_tcp
+  # windows/shell/reverse_tcp
   #
   def promptname
-    self.class.promptname
+    refname
   end
 
   #
@@ -73,6 +82,10 @@ module Msf::Module::FullName
   # reverse_tcp
   #
   def shortname
-    self.class.shortname
+    refname.split('/').last
+  end
+
+  def aliases
+    self.class.aliases
   end
 end
