@@ -109,7 +109,8 @@ class MetasploitModule < Msf::Exploit::Local
     end
     vprint_good 'abrt-ccpp service is running'
 
-    abrt_version = cmd_exec('yum list installed abrt | grep abrt').split(/\s+/)[1]
+    pkg_info = cmd_exec('yum list installed abrt | grep abrt').to_s
+    abrt_version = pkg_info[/^abrt.*$/].to_s.split(/\s+/)[1]
     unless abrt_version.blank?
       vprint_status "System is using ABRT package version #{abrt_version}"
     end
